import { Construct } from "constructs";
import { TerraformElement } from "./terraform-element";
import { TerraformProvider } from "./terraform-provider";
export interface ITerraformResource {
    readonly terraformResourceType: string;
    readonly fqn: string;
    readonly friendlyUniqueId: string;
    dependsOn?: string[];
    count?: number;
    provider?: TerraformProvider;
    lifecycle?: TerraformResourceLifecycle;
}
export interface TerraformResourceLifecycle {
    readonly createBeforeDestroy?: boolean;
    readonly preventDestroy?: boolean;
    readonly ignoreChanges?: string[];
}
export interface TerraformMetaArguments {
    readonly dependsOn?: TerraformResource[];
    readonly count?: number;
    readonly provider?: TerraformProvider;
    readonly lifecycle?: TerraformResourceLifecycle;
}
export interface TerraformGeneratorMetadata {
    readonly providerName: string;
    readonly providerVersionConstraint?: string;
}
export interface TerraformResourceConfig extends TerraformMetaArguments {
    readonly terraformResourceType: string;
    readonly terraformGeneratorMetadata?: TerraformGeneratorMetadata;
}
export declare class TerraformResource extends TerraformElement implements ITerraformResource {
    readonly terraformResourceType: string;
    readonly terraformGeneratorMetadata?: TerraformGeneratorMetadata;
    private readonly rawOverrides;
    dependsOn?: string[];
    count?: number;
    provider?: TerraformProvider;
    lifecycle?: TerraformResourceLifecycle;
    constructor(scope: Construct, id: string, config: TerraformResourceConfig);
    getStringAttribute(terraformAttribute: string): string;
    getNumberAttribute(terraformAttribute: string): number;
    getListAttribute(terraformAttribute: string): string[];
    getBooleanAttribute(terraformAttribute: string): boolean;
    addOverride(path: string, value: any): void;
    get fqn(): string;
    get terraformMetaArguments(): {
        [name: string]: any;
    };
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    /**
     * Adds this resource to the terraform JSON output.
     */
    toTerraform(): any;
    private interpolationForAttribute;
}
